const path = require('path')
const webpack = require('webpack')
const UglifyJSPlugin = require('uglifyjs-webpack-plugin')
const __dev__ = process.env.NODE_ENV === 'development'

const components = [
  'nav',
  'code-widget'
]

const config = components.map(component => ({
  mode: process.env.NODE_ENV,
  entry: {
    'index': [
      `./src/${component}/index.js`,
      `./src/${component}/standalone.js`
    ]
  },
  module: {
    rules: [
      {
        test: /.js$/,
        exclude: /node_modules/,
        use: {
          loader: 'babel-loader',
          options: {
            presets: ['react', 'es2015'],
            plugins: ['transform-strict-mode']
          }
        }
      }
    ]
  },
  output: {
    path: path.join(__dirname, 'public', component),
    filename: '[name].js'
  },
  plugins: [
    new webpack.optimize.ModuleConcatenationPlugin(),
    new webpack.DefinePlugin({
      'process.env.NODE_ENV': JSON.stringify(process.env.NODE_ENV),
      '__dev__': __dev__
    })
  ].concat(__dev__ ? [] : new UglifyJSPlugin({
    parallel: true,
    extractComments: true,
    uglifyOptions: {ie8: false, ecma: 6}
  }))
}))

const report = (err, stats) => {
  if (err) console.error(err)
  if (stats) console.log(stats.toString({ chunks: false, colors: true }))
}

if (__dev__) {
  webpack(config).watch({ignored: /node_modules/}, report)
} else {
  webpack(config).run(report)
}